@@ -490,7 +490,7 @@ class Request(object):
             if protobuf_types:
                 return protobuf_types.decode(buffer)
             else:
-                return protobuf_types
+                return buffer
 
         return None
 
